@@ -15,12 +15,13 @@ STATUS_CHOICES = [
 
 
 class Circle(Model):
-    name = models.CharField(max_length=255)
+    name = models.CharField(max_length=255, blank=True)
     description = models.CharField(max_length=255, blank=True)
     creationDate = models.DateField(auto_now_add=True)
     status = models.CharField(max_length=8, choices=STATUS_CHOICES, default='Public')
     team = models.ManyToManyField(settings.AUTH_USER_MODEL, through="CircleMember", blank=True)
-    owner = models.ForeignKey(settings.AUTH_USER_MODEL, related_name="owned_circles", on_delete=models.DO_NOTHING)
+    owner = models.ForeignKey(settings.AUTH_USER_MODEL, related_name="owned_circles", on_delete=models.DO_NOTHING,
+                              null=True, blank=True)
     jabberID = models.CharField(max_length=255, blank=True, null=True, unique=True)
     jabberRoom = models.BooleanField(default=True)
 
@@ -52,6 +53,7 @@ class CircleMember(Model):
         authenticated_perms = []
         owner_perms = []
         unique_together = ['user', 'circle']
+        rdf_type='hd:circlemember'
 
     def save(self, *args, **kwargs):
         # cannot be duplicated CircleMembers
@@ -77,5 +79,5 @@ def set_jabberid(sender, instance, **kwargs):
 @receiver(post_save, sender=Circle)
 def set_owner_as_member(instance, created, **kwargs):
     # add owner as an admin member
-    if created and not instance.members.filter(user=instance.owner).exists():
+    if created and instance.owner is not None and not instance.members.filter(user=instance.owner).exists():
         CircleMember.objects.create(user=instance.owner, circle=instance, is_admin=True)
